
# This file was automatically generated by Dist::Zilla::Plugin::ModuleBuild v5.013.
use strict;
use warnings;

use Module::Build 0.3601;


my %module_build_args = (
  "build_requires" => {
    "Module::Build" => "0.3601"
  },
  "configure_requires" => {
    "Module::Build" => "0.3601"
  },
  "dist_abstract" => "routing helper for RESTful operations",
  "dist_author" => [
    "Jens Berthold <cpan-mp-restroutes\@jebecs.de>"
  ],
  "dist_name" => "Mojolicious-Plugin-RESTRoutes",
  "dist_version" => "0.010007",
  "license" => "mit",
  "module_name" => "Mojolicious::Plugin::RESTRoutes",
  "recommends" => {},
  "recursive_test_files" => 1,
  "requires" => {
    "Lingua::EN::Inflect" => "1.895",
    "Modern::Perl" => "1.20121103",
    "Mojo::Base" => 0,
    "perl" => "v5.8.8"
  },
  "script_files" => [],
  "test_requires" => {
    "MojoX::Log::Log4perl" => "0.09",
    "Test::Mojo" => 0
  }
);


my %fallback_build_requires = (
  "Module::Build" => "0.3601",
  "MojoX::Log::Log4perl" => "0.09",
  "Test::Mojo" => 0
);


unless ( eval { Module::Build->VERSION(0.4004) } ) {
  delete $module_build_args{test_requires};
  $module_build_args{build_requires} = \%fallback_build_requires;
}

my $build = Module::Build->new(%module_build_args);

$build->create_build_script;
